@@ -1,4 +1,42 @@
-#' @export
+#' Calculates confidence intervals of the weights
+#' 
+#' \code{confidence.interval}, a method for objects of class \code{nn},
+#' typically produced by \code{neuralnet}.  Calculates confidence intervals of
+#' the weights (White, 1989) and the network information criteria NIC (Murata
+#' et al. 1994). All confidence intervals are calculated under the assumption
+#' of a local identification of the given neural network.  If this assumption
+#' is violated, the results will not be reasonable. Please make also sure that
+#' the chosen error function equals the negative log-likelihood function,
+#' otherwise the results are not meaningfull, too.
+#' 
+#' 
+#' @param x neural network
+#' @param alpha numerical. Sets the confidence level to (1-alpha).
+#' @return \code{confidence.interval} returns a list containing the following
+#' components:
+#' 
+#' \item{ lower.ci }{a list containing the lower confidence bounds of all
+#' weights of the neural network differentiated by the repetitions.} \item{
+#' upper.ci }{a list containing the upper confidence bounds of all weights of
+#' the neural network differentiated by the repetitions.} \item{ nic }{a vector
+#' containg the information criteria NIC for every repetition.}
+#' @author Stefan Fritsch, Frauke Guenther \email{guenther@@leibniz-bips.de}
+#' @seealso \code{\link{neuralnet}}
+#' @references White (1989) \emph{Learning in artificial neural networks. A
+#' statistical perspective.} Neural Computation (1), pages 425-464
+#' 
+#' Murata et al. (1994) \emph{Network information criterion - determining the
+#' number of hidden units for an artificial neural network model.} IEEE
+#' Transactions on Neural Networks 5 (6), pages 865-871
+#' @keywords neural
+#' @examples
+#' 
+#'     data(infert, package="datasets")
+#'     print(net.infert <- neuralnet(case~parity+induced+spontaneous,  
+#'                         infert, err.fct="ce", linear.output=FALSE))
+#'     confidence.interval(net.infert)
+#' 
+#' @export confidence.interval
 confidence.interval <-
 function (x, alpha = 0.05) 
 {
@@ -54,7 +92,7 @@ function (covariate, response, weights, err.fct, act.fct, exclude,
     linear.output) 
 {
     temp <- act.fct
-    if (type(act.fct) == "logistic") {
+    if (attr(act.fct, "type") == "logistic") {
         act.deriv.fct <- function(x) {
             act.fct(x) * (1 - act.fct(x))
         }
@@ -64,13 +102,13 @@ function (covariate, response, weights, err.fct, act.fct, exclude,
     }
     else {
         attr(temp, "type") <- NULL
-        act.deriv.fct <- differentiate(temp)
-        act.deriv2.fct <- differentiate(temp, hessian = T)
+        act.deriv.fct <- Deriv::Deriv(temp, nderiv = 1, x = "x")
+        act.deriv2.fct <- Deriv::Deriv(temp, nderiv = 2, x = "x")
     }
     temp <- err.fct
     attr(temp, "type") <- NULL
-    err.deriv.fct <- differentiate(temp)
-    err.deriv2.fct <- differentiate(temp, hessian = T)
+    err.deriv.fct <- Deriv::Deriv(temp, nderiv = 1, x = "x")
+    err.deriv2.fct <- Deriv::Deriv(temp, nderiv = 2, x = "x")
     length.weights <- length(weights)
     nrow.weights <- sapply(weights, nrow)
     ncol.weights <- sapply(weights, ncol)
@@ -116,7 +154,7 @@ function (covariate, response, weights, err.fct, act.fct, exclude,
         warning("neuron.deriv2 contains NA; this might be caused by a wrong choice of 'act.fct'")
     }
     if (any(is.na(err.deriv)) || any(is.na(err.deriv2))) {
-        if (type(err.fct) == "ce") {
+        if (attr(err.fct, "type") == "ce") {
             one <- which(net.result == 1)
             if (length(one) > 0) {
                 for (i in 1:length(one)) {
